# -*- coding: utf-8 -*-

from django import forms
from instant.utils import _get_public_channel
from instant.conf import ENABLE_USERS_CHANNEL, ENABLE_STAFF_CHANNEL, ENABLE_SUPERUSER_CHANNEL, PUBLIC_CHANNEL, USERS_CHANNELS, STAFF_CHANNELS, SUPERUSER_CHANNELS

choices = [((PUBLIC_CHANNEL, 'Public'))]
if ENABLE_USERS_CHANNEL is True:
    for channel in USERS_CHANNELS:
        choices.append((channel, channel))
if ENABLE_STAFF_CHANNEL is True:
    for channel in STAFF_CHANNELS:
        choices.append((channel, channel))
if ENABLE_SUPERUSER_CHANNEL is True:
    for channel in SUPERUSER_CHANNELS:
        choices.append((channel, channel))

class BroadcastForm(forms.Form):
    message = forms.CharField(
                              max_length=300, 
                              label="Message", 
                              widget=forms.Textarea(attrs={'rows':'2'}), 
                              required=True
                              )
    event_class = forms.CharField(
                                  max_length=60, 
                                  label="Event class", 
                                  required=False
                                  )
    default_channel = forms.CharField(
                                  max_length=60,
                                  label="Channels",
                                  required=False,
                                  widget=forms.RadioSelect(choices=choices),
                                  )
    channel = forms.CharField(
                                  max_length=60, 
                                  label="Other channel", 
                                  required=False
                                  )


# -*- coding: utf-8 -*-

import time
from django import template
from django.template.defaultfilters import stringfilter
from django.conf import settings
from cent.core import generate_token


DEBUG = False

try:
    SECRET_KEY = getattr(settings, 'CENTRIFUGO_SECRET_KEY')
except ImportError:
    raise ImproperlyConfigured(u"The Centrifugo secret key must be set in settings.py with CENTRIFUGO_SECRET_KEY")
SITE_SLUG =  getattr(settings, 'SITE_SLUG', 'site')
CENTRIFUGO_HOST = getattr(settings, 'CENTRIFUGO_HOST', 'http://localhost')
CENTRIFUGO_PORT = getattr(settings, 'CENTRIFUGO_PORT', 8001)

REDIS_HOST = getattr(settings, 'MQUEUE_REDIS_HOST', 'localhost')
REDIS_PORT = getattr(settings, 'MQUEUE_REDIS_PORT', 6379)
REDIS_DB = getattr(settings, 'MQUEUE_REDIS_DB', 0)

GLOBAL_STREAMS =  getattr(settings, 'INSTANT_GLOBAL_STREAMS', ())
APPS =  getattr(settings, 'INSTANT_APPS', [])

ENABLE_STAFF_CHANNEL = getattr(settings, 'INSTANT_ENABLE_STAFF_CHANNEL', False)
ENABLE_USERS_CHANNEL = getattr(settings, 'INSTANT_ENABLE_USERS_CHANNEL', False)
ENABLE_SUPERUSER_CHANNEL = getattr(settings, 'INSTANT_ENABLE_SUPERUSER_CHANNEL', False)

# javascript debug messages
debug_mode = getattr(settings, 'INSTANT_DEBUG', False)
if debug_mode is True:
    DEBUG_MODE = "true"
else:
    DEBUG_MODE = "false"

def _get_public_channel():
    channel = SITE_SLUG+'_public'
    if 'public' in GLOBAL_STREAMS:
        channel = "public"
    return channel

register = template.Library()

@register.simple_tag
def get_centrifugo_url():
    return CENTRIFUGO_HOST+":"+str(CENTRIFUGO_PORT)

@register.simple_tag
def debug_mode():
    return DEBUG_MODE

@register.simple_tag
def get_timestamp():
    return str(int(time.time()))

@register.simple_tag
def mq_generate_token(user, timestamp, info=""):
    token = generate_token(SECRET_KEY, user, timestamp, info)
    if DEBUG is True:
        print "Generating token:"
        print "Key: "+SECRET_KEY
        print "User: "+user
        print "Timestamp: "+timestamp
        print "Generated token for user "+user+" at "+timestamp+": "+token
    return token

@register.simple_tag
def get_public_channel():
    return _get_public_channel()

@register.simple_tag
def is_users_channel(): 
    return ENABLE_USERS_CHANNEL

@register.simple_tag
def get_users_channel(): 
    return '$'+SITE_SLUG+'_users'

@register.simple_tag
def is_staff_channel(): 
    return ENABLE_STAFF_CHANNEL

@register.simple_tag
def get_staff_channel(): 
    return '$'+SITE_SLUG+'_staff'

@register.simple_tag
def is_superuser_channel(): 
    return ENABLE_SUPERUSER_CHANNEL

@register.simple_tag
def get_superuser_channel(): 
    return '$'+SITE_SLUG+'_admin'

@register.simple_tag
def get_apps():
    return APPS

@register.filter
@stringfilter
def is_in_apps(app):
    if app in APPS:
        return True
    else:
        return False


# -*- coding: utf-8 -*-

from django.core.exceptions import ImproperlyConfigured
from django.conf import settings


try:
    SECRET_KEY = getattr(settings, 'CENTRIFUGO_SECRET_KEY')
except ImportError:
    raise ImproperlyConfigured(u"The Centrifugo secret key must be set in settings.py with CENTRIFUGO_SECRET_KEY")
CENTRIFUGO_HOST = getattr(settings, 'CENTRIFUGO_HOST', 'http://localhost')
CENTRIFUGO_PORT = getattr(settings, 'CENTRIFUGO_PORT', 8001)

SITE_SLUG =  getattr(settings, 'SITE_SLUG', 'site')
SITE_NAME =  getattr(settings, 'SITE_NAME', 'Site')

BROADCAST_WITH = getattr(settings, 'INSTANT_BROADCAST_WITH', "py")

ENABLE_USERS_CHANNEL = getattr(settings, 'INSTANT_ENABLE_USERS_CHANNEL', False)
ENABLE_STAFF_CHANNEL = getattr(settings, 'INSTANT_ENABLE_STAFF_CHANNEL', False)
ENABLE_SUPERUSER_CHANNEL = getattr(settings, 'INSTANT_ENABLE_SUPERUSER_CHANNEL', False)

public_channel = SITE_SLUG+'_public'
PUBLIC_CHANNEL =  getattr(settings, 'INSTANT_PUBLIC_CHANNEL', public_channel)
USERS_CHANNELS =  getattr(settings, 'INSTANT_USERS_CHANNELS', [])
STAFF_CHANNELS =  getattr(settings, 'INSTANT_STAFF_CHANNELS', [])
SUPERUSER_CHANNELS =  getattr(settings, 'INSTANT_SUPERUSER_CHANNELS', [])
# add default channels
if ENABLE_USERS_CHANNEL is True:
    USERS_CHANNELS.append("$"+SITE_SLUG+"_users")
if ENABLE_STAFF_CHANNEL is True:
    STAFF_CHANNELS.append("$"+SITE_SLUG+"_staff")
if ENABLE_SUPERUSER_CHANNEL is True:
    SUPERUSER_CHANNELS.append("$"+SITE_SLUG+"_admin")

# ensure that the private channels will always be treated as private by Centrifugo
chans = []
for chan in USERS_CHANNELS:
    if not chan.startswith("$"):
        chan = u"$"+chan
    chans.append(chan)
USERS_CHANNELS = chans
schans = []
for chan in STAFF_CHANNELS:
    if not chan.startswith("$"):
        chan = u"$"+chan
    schans.append(chan)
STAFF_CHANNELS = schans
achans = []
for chan in SUPERUSER_CHANNELS:
    if not chan.startswith("$"):
        chan = u"$"+chan
    achans.append(chan)
SUPERUSER_CHANNELS = achans